@@ -547,10 +547,10 @@ _SPECIFICATIONS: Registry[Specification[Schema]] = Registry(
         for dialect_id, specification in [
             ("https://json-schema.org/draft/2020-12/schema", DRAFT202012),
             ("https://json-schema.org/draft/2019-09/schema", DRAFT201909),
-            ("http://json-schema.org/draft-07/schema#", DRAFT7),
-            ("http://json-schema.org/draft-06/schema#", DRAFT6),
-            ("http://json-schema.org/draft-04/schema#", DRAFT4),
-            ("http://json-schema.org/draft-03/schema#", DRAFT3),
+            ("http://json-schema.org/draft-07/schema", DRAFT7),
+            ("http://json-schema.org/draft-06/schema", DRAFT6),
+            ("http://json-schema.org/draft-04/schema", DRAFT4),
+            ("http://json-schema.org/draft-03/schema", DRAFT3),
         ]
     },
 )
@@ -569,7 +569,7 @@ def specification_with(
 
             if the given ``dialect_id`` isn't known
     """
-    resource = _SPECIFICATIONS.get(dialect_id)
+    resource = _SPECIFICATIONS.get(dialect_id.rstrip("#"))
     if resource is not None:
         return resource.contents
     if default is None:  # type: ignore[reportUnnecessaryComparison]
